@@ -64,9 +64,9 @@ const DEFAULT_RET_VALUE_SIZE_WEIGHT: u32 = 420;
 
 const DEFAULT_REVERT_COST: u32 = 500;
 const DEFAULT_SET_ACTION_THRESHOLD_COST: u32 = 74_000;
-const DEFAULT_TRANSFER_FROM_PURSE_TO_ACCOUNT_COST: u32 = 160_000;
+const DEFAULT_TRANSFER_FROM_PURSE_TO_ACCOUNT_COST: u32 = 2_500_000_000;
 const DEFAULT_TRANSFER_FROM_PURSE_TO_PURSE_COST: u32 = 82_000;
-const DEFAULT_TRANSFER_TO_ACCOUNT_COST: u32 = 24_000;
+const DEFAULT_TRANSFER_TO_ACCOUNT_COST: u32 = 2_500_000_000;
 const DEFAULT_UPDATE_ASSOCIATED_KEY_COST: u32 = 4_200;
 
 const DEFAULT_WRITE_COST: u32 = 14_000;
